==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/CSIPersistentVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CSIPersistentVolumeSourceFluent<A extends io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildControllerExpandSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretReference getControllerExpandSecretRef();
  public io.fabric8.kubernetes.api.model.SecretReference buildControllerExpandSecretRef();
  public A withControllerExpandSecretRef(io.fabric8.kubernetes.api.model.SecretReference controllerExpandSecretRef);
  public java.lang.Boolean hasControllerExpandSecretRef();
  public A withNewControllerExpandSecretRef(java.lang.String name,java.lang.String namespace);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> withNewControllerExpandSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> withNewControllerExpandSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> editControllerExpandSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> editOrNewControllerExpandSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> editOrNewControllerExpandSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  
  /**
   * This method has been deprecated, please use method buildControllerPublishSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretReference getControllerPublishSecretRef();
  public io.fabric8.kubernetes.api.model.SecretReference buildControllerPublishSecretRef();
  public A withControllerPublishSecretRef(io.fabric8.kubernetes.api.model.SecretReference controllerPublishSecretRef);
  public java.lang.Boolean hasControllerPublishSecretRef();
  public A withNewControllerPublishSecretRef(java.lang.String name,java.lang.String namespace);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> withNewControllerPublishSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> withNewControllerPublishSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editControllerPublishSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editOrNewControllerPublishSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editOrNewControllerPublishSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  public java.lang.String getDriver();
  public A withDriver(java.lang.String driver);
  public java.lang.Boolean hasDriver();
  
  /**
   * Method is deprecated. use withDriver instead.
   */
  @java.lang.Deprecated
  public A withNewDriver(java.lang.String arg0);
  public java.lang.String getFsType();
  public A withFsType(java.lang.String fsType);
  public java.lang.Boolean hasFsType();
  
  /**
   * Method is deprecated. use withFsType instead.
   */
  @java.lang.Deprecated
  public A withNewFsType(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildNodePublishSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretReference getNodePublishSecretRef();
  public io.fabric8.kubernetes.api.model.SecretReference buildNodePublishSecretRef();
  public A withNodePublishSecretRef(io.fabric8.kubernetes.api.model.SecretReference nodePublishSecretRef);
  public java.lang.Boolean hasNodePublishSecretRef();
  public A withNewNodePublishSecretRef(java.lang.String name,java.lang.String namespace);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editNodePublishSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  
  /**
   * This method has been deprecated, please use method buildNodeStageSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretReference getNodeStageSecretRef();
  public io.fabric8.kubernetes.api.model.SecretReference buildNodeStageSecretRef();
  public A withNodeStageSecretRef(io.fabric8.kubernetes.api.model.SecretReference nodeStageSecretRef);
  public java.lang.Boolean hasNodeStageSecretRef();
  public A withNewNodeStageSecretRef(java.lang.String name,java.lang.String namespace);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> withNewNodeStageSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> withNewNodeStageSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editNodeStageSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editOrNewNodeStageSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editOrNewNodeStageSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  public java.lang.Boolean getReadOnly();
  public A withReadOnly(java.lang.Boolean readOnly);
  public java.lang.Boolean hasReadOnly();
  public A addToVolumeAttributes(java.lang.String key,java.lang.String value);
  public A addToVolumeAttributes(java.util.Map<java.lang.String,java.lang.String> map);
  public A removeFromVolumeAttributes(java.lang.String key);
  public A removeFromVolumeAttributes(java.util.Map<java.lang.String,java.lang.String> map);
  public java.util.Map<java.lang.String,java.lang.String> getVolumeAttributes();
  public <K,V>A withVolumeAttributes(java.util.Map<java.lang.String,java.lang.String> volumeAttributes);
  public java.lang.Boolean hasVolumeAttributes();
  public java.lang.String getVolumeHandle();
  public A withVolumeHandle(java.lang.String volumeHandle);
  public java.lang.Boolean hasVolumeHandle();
  
  /**
   * Method is deprecated. use withVolumeHandle instead.
   */
  @java.lang.Deprecated
  public A withNewVolumeHandle(java.lang.String arg0);
  public interface ControllerExpandSecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SecretReferenceFluent<io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<N>>{
    public N and();
    public N endControllerExpandSecretRef();
    
  }
  public interface ControllerPublishSecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SecretReferenceFluent<io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<N>>{
    public N and();
    public N endControllerPublishSecretRef();
    
  }
  public interface NodePublishSecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SecretReferenceFluent<io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<N>>{
    public N and();
    public N endNodePublishSecretRef();
    
  }
  public interface NodeStageSecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SecretReferenceFluent<io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<N>>{
    public N and();
    public N endNodeStageSecretRef();
    
  }
  
}

==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/CSIPersistentVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CSIPersistentVolumeSourceFluent<A extends io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildControllerExpandSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretReference getControllerExpandSecretRef();
  public io.fabric8.kubernetes.api.model.SecretReference buildControllerExpandSecretRef();
  public A withControllerExpandSecretRef(io.fabric8.kubernetes.api.model.SecretReference controllerExpandSecretRef);
  public java.lang.Boolean hasControllerExpandSecretRef();
  public A withNewControllerExpandSecretRef(java.lang.String name,java.lang.String namespace);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> withNewControllerExpandSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> withNewControllerExpandSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> editControllerExpandSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> editOrNewControllerExpandSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<A> editOrNewControllerExpandSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  
  /**
   * This method has been deprecated, please use method buildControllerPublishSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretReference getControllerPublishSecretRef();
  public io.fabric8.kubernetes.api.model.SecretReference buildControllerPublishSecretRef();
  public A withControllerPublishSecretRef(io.fabric8.kubernetes.api.model.SecretReference controllerPublishSecretRef);
  public java.lang.Boolean hasControllerPublishSecretRef();
  public A withNewControllerPublishSecretRef(java.lang.String name,java.lang.String namespace);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> withNewControllerPublishSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> withNewControllerPublishSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editControllerPublishSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editOrNewControllerPublishSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editOrNewControllerPublishSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  public java.lang.String getDriver();
  public A withDriver(java.lang.String driver);
  public java.lang.Boolean hasDriver();
  
  /**
   * Method is deprecated. use withDriver instead.
   */
  @java.lang.Deprecated
  public A withNewDriver(java.lang.String arg0);
  public java.lang.String getFsType();
  public A withFsType(java.lang.String fsType);
  public java.lang.Boolean hasFsType();
  
  /**
   * Method is deprecated. use withFsType instead.
   */
  @java.lang.Deprecated
  public A withNewFsType(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildNodePublishSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretReference getNodePublishSecretRef();
  public io.fabric8.kubernetes.api.model.SecretReference buildNodePublishSecretRef();
  public A withNodePublishSecretRef(io.fabric8.kubernetes.api.model.SecretReference nodePublishSecretRef);
  public java.lang.Boolean hasNodePublishSecretRef();
  public A withNewNodePublishSecretRef(java.lang.String name,java.lang.String namespace);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editNodePublishSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  
  /**
   * This method has been deprecated, please use method buildNodeStageSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretReference getNodeStageSecretRef();
  public io.fabric8.kubernetes.api.model.SecretReference buildNodeStageSecretRef();
  public A withNodeStageSecretRef(io.fabric8.kubernetes.api.model.SecretReference nodeStageSecretRef);
  public java.lang.Boolean hasNodeStageSecretRef();
  public A withNewNodeStageSecretRef(java.lang.String name,java.lang.String namespace);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> withNewNodeStageSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> withNewNodeStageSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editNodeStageSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editOrNewNodeStageSecretRef();
  public io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editOrNewNodeStageSecretRefLike(io.fabric8.kubernetes.api.model.SecretReference item);
  public java.lang.Boolean getReadOnly();
  public A withReadOnly(java.lang.Boolean readOnly);
  public java.lang.Boolean hasReadOnly();
  public A addToVolumeAttributes(java.lang.String key,java.lang.String value);
  public A addToVolumeAttributes(java.util.Map<java.lang.String,java.lang.String> map);
  public A removeFromVolumeAttributes(java.lang.String key);
  public A removeFromVolumeAttributes(java.util.Map<java.lang.String,java.lang.String> map);
  public java.util.Map<java.lang.String,java.lang.String> getVolumeAttributes();
  public <K,V>A withVolumeAttributes(java.util.Map<java.lang.String,java.lang.String> volumeAttributes);
  public java.lang.Boolean hasVolumeAttributes();
  public java.lang.String getVolumeHandle();
  public A withVolumeHandle(java.lang.String volumeHandle);
  public java.lang.Boolean hasVolumeHandle();
  
  /**
   * Method is deprecated. use withVolumeHandle instead.
   */
  @java.lang.Deprecated
  public A withNewVolumeHandle(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ControllerExpandSecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SecretReferenceFluent<io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerExpandSecretRefNested<N>>{
    public N and();
    public N endControllerExpandSecretRef();
    
  }
  public interface ControllerPublishSecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SecretReferenceFluent<io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<N>>{
    public N and();
    public N endControllerPublishSecretRef();
    
  }
  public interface NodePublishSecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SecretReferenceFluent<io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<N>>{
    public N and();
    public N endNodePublishSecretRef();
    
  }
  public interface NodeStageSecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SecretReferenceFluent<io.fabric8.kubernetes.api.model.CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<N>>{
    public N and();
    public N endNodeStageSecretRef();
    
  }
  
}
